# Colortheme
[![PyPI version](https://badge.fury.io/py/colortheme.svg)](https://badge.fury.io/py/colortheme)
![Python version](https://img.shields.io/badge/python-3.10+-brightgreen)
![Operating system](https://img.shields.io/badge/os-linux%20%7c%20macOS%20%7c%20windows-brightgreen)
![Coverage](https://img.shields.io/badge/coverage-100%25-brightgreen)

## Usage

Run
```shell
colortheme
```
## Installation
```shell
pip install colortheme
```
